import React from 'react';
import FullCalendar from '@fullcalendar/react';
import dayGridPlugin from '@fullcalendar/daygrid';
import timeGridPlugin from '@fullcalendar/timegrid';
import interaction from '@fullcalendar/interaction';
import scrollGrid from '@fullcalendar/scrollgrid';
import { DateTime } from 'luxon';
import { Icon, IconButton } from 'rsuite';

// FullCalendar props
const dayMinWidth = 110;

export default function IntervalSelector({
	selectedDates,
	handleSelect,
	availability,
	setAvailability,
	slotMinTime,
	slotMaxTime,
}) {
	/// DATES DISPLAY
	let startDate = selectedDates[0].start;
	// create a Datetime object from the last event date,
	// add one day, and change it to a date string
	let lastEventDate = selectedDates[selectedDates.length - 1].start;
	let endDate = DateTime.fromFormat(lastEventDate, 'yyyy-MM-dd')
		.plus({ days: 1 })
		.toFormat('yyyy-MM-dd');

	// Create an event dates list used to create the days columns
	const daysList = selectedDates.map((event) => event.start);

	console.log(daysList);

	const handleDayDidMount = ({ date, el }) => {
		let currentDate = DateTime.fromJSDate(date).toFormat('yyyy-MM-dd');
		if (!daysList.includes(currentDate)) {
			if (el) {
				el.remove();
			}
		}
	};
	const handleViewMount = ({ el }) => {
		// Adapt column width to number of dates present
		const timegridBody = el.querySelectorAll('div.fc-timegrid-body');
		const timegridSlots = el.querySelectorAll('div.fc-timegrid-slots');
		const timegridScroll = el.querySelectorAll(
			'.fc-col-header.fc-scrollgrid-sync-table',
		);

		console.log(timegridScroll);

		// Update width based on rendered dates number
		let newWidth = daysList.length * dayMinWidth;
		timegridBody[0].style['min-width'] = `${newWidth}px`;
		timegridSlots[0].style['min-width'] = `${newWidth}px`;
		timegridScroll[0].style['min-width'] = `${newWidth}px`;
	};

	/// AVAILABILITY INTERACTION
	const handleClick = (eventStart, eventEnd) => {
		let updatedAvailability = [];
		// Create an event object to compare
		let currentAvailability = {
			start: eventStart,
			end: eventEnd,
		};
		// Make it to JSON
		let currentAvJson = JSON.stringify(currentAvailability);

		// Create an array of stringified availability
		let avListJson = availability.map((event) => {
			delete event['id'];
			return JSON.stringify(event);
		});

		// Check if there's a similar event obj in the availability
		let index = avListJson.findIndex(
			(availability) => currentAvJson === availability,
		);

		// Remove event from availability at index
		if (index > -1) {
			updatedAvailability = [...availability];
			updatedAvailability.splice(index, 1);
		}

		setAvailability([...updatedAvailability]);
	};

	const handleContent = ({ event }) => {
		let eventStart = event.start;
		let eventEnd = event.end;

		let evStartDT = DateTime.fromJSDate(eventStart);
		let evEndDT = DateTime.fromJSDate(eventEnd);

		return (
			<>
				<div
					style={{
						display: 'flex',
						justifyContent: 'space-between',
						alignItems: 'center',
						flexDirection: 'row',
					}}
				>
					<p>
						{evStartDT.toFormat('HH:mm')} -{' '}
						{evEndDT.toFormat('HH:mm')}
					</p>
					<IconButton
						className={'event-close'}
						icon={<Icon icon='close' />}
						appearance='default'
						size='xs'
						circle
						onClick={() => handleClick(eventStart, eventEnd)}
					></IconButton>
				</div>
			</>
		);
	};

	console.log(startDate, endDate);

	return (
		<FullCalendar
			plugins={[dayGridPlugin, interaction, timeGridPlugin, scrollGrid]}
			events={availability}
			// View props
			headerToolbar={{ right: '' }}
			initialView='timeGrid'
			visibleRange={{
				start: startDate,
				end: endDate,
			}}
			allDaySlot={false}
			dayMinWidth={dayMinWidth}
			dayHeaderFormat={{
				weekday: 'short',
				day: 'numeric',
				month: 'short',
				omitCommas: true,
			}}
			slotMinTime={slotMinTime}
			slotMaxTime={slotMaxTime}
			dayCellDidMount={(arg) => handleDayDidMount(arg)}
			dayHeaderDidMount={(arg) => handleDayDidMount(arg)}
			viewDidMount={(arg) => handleViewMount(arg)}
			// Interaction props
			selectable={true}
			unselectAuto={true}
			selectOverlap={false}
			select={(info) => handleSelect(info)}
			longPressDelay={150}
			eventContent={(arg) => handleContent(arg)}
		/>
	);
}
